@@ -117,30 +117,32 @@ def process_include_statements(root):
             tag = NAMESPACE_PAT.sub("", tag)
         else:
             tag = None
-        if tag == 'include' and 'schemaLocation' in child.attrib:
-            idx += 1
-            locn = child.attrib['schemaLocation']
-            path = child.attrib['schemaLocation']
-            if path in alreadyProcessed:
-                root.remove(child)
-                continue
-            repl = etree.Comment(etree.tostring(child))
-            root.replace(child, repl)
-            path1 = make_path(root, path)
-            if os.path.exists(path1):
-                process_path(root, idx, path1)
-            else:
-                for d in DIRPATH:
-                    path = make_path(root, path)
-                    path1 = os.path.join(d,locn)
-                    if os.path.exists(path1):
-                        process_path(root, idx, path1)
-                        break
-                else:
-                    msg = "Can't find include file %s.  Aborting." % (path, )
-                    raise IOError(msg)
-            alreadyProcessed.add(path)
-        elif tag == 'import' and 'schemaLocation' in child.attrib:
+##         if tag == 'include' and 'schemaLocation' in child.attrib:
+##             idx += 1
+##             locn = child.attrib['schemaLocation']
+##             path = child.attrib['schemaLocation']
+##             if path in alreadyProcessed:
+##                 root.remove(child)
+##                 continue
+##             repl = etree.Comment(etree.tostring(child))
+##             root.replace(child, repl)
+##             path1 = make_path(root, path)
+##             if os.path.exists(path1):
+##                 process_path(root, idx, path1)
+##             else:
+##                 for d in DIRPATH:
+##                     path = make_path(root, path)
+##                     path1 = os.path.join(d,locn)
+##                     if os.path.exists(path1):
+##                         process_path(root, idx, path1)
+##                         break
+##                 else:
+##                     msg = "Can't find include file %s.  Aborting." % (path, )
+##                     raise IOError(msg)
+##             alreadyProcessed.add(path)
+##         elif ((tag == 'include' or tag == 'import') and
+        if ((tag == 'include' or tag == 'import') and
+            'schemaLocation' in child.attrib):
             idx += 1
             locn = child.attrib['schemaLocation']
             if locn in alreadyProcessed:
@@ -193,7 +195,7 @@ def split_base_path(path):
 
 def make_path(root, path):
     path1 = root.get('path_', '.')
-    path2 = '%s/%s' % (path1, path, )
+    path2 = os.path.join(path1, path)
     return path2
 
 
